summaryrefslogtreecommitdiffstats
path: root/karbon/core/vstroke.cc
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /karbon/core/vstroke.cc
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'karbon/core/vstroke.cc')
-rw-r--r--karbon/core/vstroke.cc42
1 files changed, 21 insertions, 21 deletions
diff --git a/karbon/core/vstroke.cc b/karbon/core/vstroke.cc
index b7431be5..0fe49e99 100644
--- a/karbon/core/vstroke.cc
+++ b/karbon/core/vstroke.cc
@@ -18,7 +18,7 @@
* Boston, MA 02110-1301, USA.
*/
-#include <qdom.h>
+#include <tqdom.h>
#include <KoGenStyles.h>
#include <KoStyleStack.h>
@@ -33,10 +33,10 @@ VStroke::VStroke()
: m_parent(0L), m_lineWidth(1.0), m_lineCap(capButt), m_lineJoin(joinMiter), m_miterLimit(10.0), m_type(none)
{}
-VStroke::VStroke( VObject* parent, float width, const VLineCap cap, const VLineJoin join,
+VStroke::VStroke( VObject* tqparent, float width, const VLineCap cap, const VLineJoin join,
float miterLimit )
{
- m_parent = parent;
+ m_parent = tqparent;
m_type = solid;
m_lineWidth = width;
m_lineCap = cap;
@@ -44,10 +44,10 @@ VStroke::VStroke( VObject* parent, float width, const VLineCap cap, const VLineJ
m_miterLimit = miterLimit;
}
-VStroke::VStroke( const VColor &c, VObject* parent, float width, const VLineCap cap, const VLineJoin join,
+VStroke::VStroke( const VColor &c, VObject* tqparent, float width, const VLineCap cap, const VLineJoin join,
float miterLimit )
{
- m_parent = parent;
+ m_parent = tqparent;
m_type = solid;
m_lineWidth = width;
m_lineCap = cap;
@@ -58,7 +58,7 @@ VStroke::VStroke( const VColor &c, VObject* parent, float width, const VLineCap
VStroke::VStroke( const VStroke& stroke )
{
- // doesn't copy parent:
+ // doesn't copy tqparent:
*this = stroke;
}
@@ -67,15 +67,15 @@ VStroke::setLineWidth( float width )
{
m_lineWidth = width;
// tell our parent so he can update his bbox:
if( m_parent )
- m_parent->invalidateBoundingBox();
+ m_parent->tqinvalidateBoundingBox();
}
void
-VStroke::save( QDomElement& element ) const
+VStroke::save( TQDomElement& element ) const
{
- QDomElement me = element.ownerDocument().createElement( "STROKE" );
+ TQDomElement me = element.ownerDocument().createElement( "STROKE" );
element.appendChild( me );
// save stroke parameters:
@@ -114,10 +114,10 @@ VStroke::saveOasis( KoGenStyle &style ) const
if( m_type == solid )
{
style.addProperty( "draw:stroke", "solid" );
- style.addProperty( "svg:stroke-color", QColor( m_color ).name() );
+ style.addProperty( "svg:stroke-color", TQColor( m_color ).name() );
style.addPropertyPt( "svg:stroke-width", m_lineWidth );
if( m_color.opacity() < 1 )
- style.addProperty( "svg:stroke-opacity", QString( "%1%" ).arg( m_color.opacity() * 100. ) );
+ style.addProperty( "svg:stroke-opacity", TQString( "%1%" ).tqarg( m_color.opacity() * 100. ) );
}
else if( m_type == none )
style.addProperty( "draw:stroke", "none" );
@@ -142,10 +142,10 @@ VStroke::loadOasis( const KoStyleStack &stack )
if( stack.attributeNS( KoXmlNS::draw, "stroke" ) == "solid" )
{
setType( VStroke::solid );
- setColor( QColor( stack.attributeNS( KoXmlNS::svg, "stroke-color" ) ) );
+ setColor( TQColor( stack.attributeNS( KoXmlNS::svg, "stroke-color" ) ) );
if( stack.hasAttributeNS( KoXmlNS::svg, "stroke-opacity" ) )
m_color.setOpacity( stack.attributeNS( KoXmlNS::svg, "stroke-opacity" ).remove( '%' ).toFloat() / 100. );
- QString join = stack.attributeNS( KoXmlNS::draw, "stroke-linejoin" );
+ TQString join = stack.attributeNS( KoXmlNS::draw, "stroke-linejoin" );
if( !join.isEmpty() )
{
if( join == "round" )
@@ -166,7 +166,7 @@ VStroke::loadOasis( const KoStyleStack &stack )
}
void
-VStroke::load( const QDomElement& element )
+VStroke::load( const TQDomElement& element )
{
m_type = none;
// load stroke parameters:
@@ -200,12 +200,12 @@ VStroke::load( const QDomElement& element )
// load color:
- QDomNodeList list = element.childNodes();
+ TQDomNodeList list = element.childNodes();
for( uint i = 0; i < list.count(); ++i )
{
if( list.item( i ).isElement() )
{
- QDomElement e = list.item( i ).toElement();
+ TQDomElement e = list.item( i ).toElement();
if( e.tagName() == "COLOR" )
{
m_color.load( e );
@@ -235,13 +235,13 @@ VStroke::operator=( const VStroke& stroke )
{
if( this != &stroke )
{
// dont copy the parent!
m_type = stroke.m_type;
m_lineWidth = stroke.m_lineWidth;
// Tell our parent about the linewidth change, so he can update his bbox:
//if( m_parent )
- // m_parent->invalidateBoundingBox();
+ // m_parent->tqinvalidateBoundingBox();
m_lineCap = stroke.m_lineCap;
m_lineJoin = stroke.m_lineJoin;
@@ -256,7 +256,7 @@ VStroke::operator=( const VStroke& stroke )
}
void
-VStroke::transform( const QWMatrix& m )
+VStroke::transform( const TQWMatrix& m )
{
if( type() == VStroke::grad )
gradient().transform( m );
@@ -67,15 +67,15 @@ VStroke::setLineWidth( float width )
{
m_lineWidth = width;
- // tell our parent so he can update his bbox:
+ // tell our tqparent so he can update his bbox:
if( m_parent )
@@ -235,13 +235,13 @@ VStroke::operator=( const VStroke& stroke )
if( this != &stroke )
{
- // dont copy the parent!
+ // dont copy the tqparent!
m_type = stroke.m_type;
m_lineWidth = stroke.m_lineWidth;
@@ -235,13 +235,13 @@ VStroke::operator=( const VStroke& stroke )
m_type = stroke.m_type;
m_lineWidth = stroke.m_lineWidth;
- // Tell our parent about the linewidth change, so he can update his bbox:
+ // Tell our tqparent about the linewidth change, so he can update his bbox:
//if( m_parent )